Welcome to Dragonfly's documentation!
=========================================

.. image:: http://www.ladybug.tools/assets/img/dragonfly.png

Dragonfly is collection of libraries to model and analyze urban climate, energy
use, and daylight. It extends the capabilites of
`honeybee-core <https://github.com/ladybug-tools/honeybee-core/>`_ for the urban scale.


Installation
============

To install the core library try ``pip install -U dragonfly-core``.

If you want to also include the command line interface try ``pip install -U dragonfly-core[cli]``.

To check if the Dragonfly command line is installed correctly try ``dragonfly viz`` and you
should get a ``viiiiiiiiiiiiizzzzzzzzz!`` back in response!


Documentation
=============

This document includes `Dragonfly API documentation <#dragonfly>`_ and 
`Dragonfly Command Line Interface <#id1>`_ documentation for ``dragonfly core`` and does
not include the documentation for dragonfly extensions. For each extension refer to
extension's documentation page.

Here are a number of popular Dragonfly extensions:

- `dragonfly-energy <https://ladybug.tools/dragonfly-energy/docs>`_


.. toctree::
   :maxdepth: 2
   :caption: Contents:

.. include:: modules.rst
.. include:: cli.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
